package com.fs.company.controller;

import java.util.List;

import com.fs.company.param.CompanyVoicePackageOrderListParam;
import com.fs.company.vo.CompanyVoicePackageOrderListVO;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.enums.BusinessType;
import com.fs.company.domain.CompanyVoicePackageOrder;
import com.fs.company.service.ICompanyVoicePackageOrderService;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.common.core.page.TableDataInfo;

/**
 * 套餐订单Controller
 * 
 * @author fs
 * @date 2023-02-23
 */
@RestController
@RequestMapping("/company/companyVoicePackageOrder")
public class CompanyVoicePackageOrderController extends BaseController
{
    @Autowired
    private ICompanyVoicePackageOrderService companyVoicePackageOrderService;

    /**
     * 查询套餐订单列表
     */
    @PreAuthorize("@ss.hasPermi('company:companyVoicePackageOrder:list')")
    @GetMapping("/list")
    public TableDataInfo list(CompanyVoicePackageOrderListParam param)
    {
        startPage();
        List<CompanyVoicePackageOrderListVO> list = companyVoicePackageOrderService.selectCompanyVoicePackageOrderListVO(param);
        return getDataTable(list);
    }

    /**
     * 导出套餐订单列表
     */
    @PreAuthorize("@ss.hasPermi('company:companyVoicePackageOrder:export')")
    @Log(title = "套餐订单", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(CompanyVoicePackageOrderListParam param)
    {
        List<CompanyVoicePackageOrderListVO> list = companyVoicePackageOrderService.selectCompanyVoicePackageOrderListVO(param);
        ExcelUtil<CompanyVoicePackageOrderListVO> util = new ExcelUtil<CompanyVoicePackageOrderListVO>(CompanyVoicePackageOrderListVO.class);
        return util.exportExcel(list, "companyVoicePackageOrder");
    }

    /**
     * 获取套餐订单详细信息
     */
    @PreAuthorize("@ss.hasPermi('company:companyVoicePackageOrder:query')")
    @GetMapping(value = "/{orderId}")
    public AjaxResult getInfo(@PathVariable("orderId") Long orderId)
    {
        return AjaxResult.success(companyVoicePackageOrderService.selectCompanyVoicePackageOrderById(orderId));
    }

    /**
     * 新增套餐订单
     */
    @PreAuthorize("@ss.hasPermi('company:companyVoicePackageOrder:add')")
    @Log(title = "套餐订单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CompanyVoicePackageOrder companyVoicePackageOrder)
    {
        return toAjax(companyVoicePackageOrderService.insertCompanyVoicePackageOrder(companyVoicePackageOrder));
    }

    /**
     * 修改套餐订单
     */
    @PreAuthorize("@ss.hasPermi('company:companyVoicePackageOrder:edit')")
    @Log(title = "套餐订单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CompanyVoicePackageOrder companyVoicePackageOrder)
    {
        return toAjax(companyVoicePackageOrderService.updateCompanyVoicePackageOrder(companyVoicePackageOrder));
    }

    /**
     * 删除套餐订单
     */
    @PreAuthorize("@ss.hasPermi('company:companyVoicePackageOrder:remove')")
    @Log(title = "套餐订单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{orderIds}")
    public AjaxResult remove(@PathVariable Long[] orderIds)
    {
        return toAjax(companyVoicePackageOrderService.deleteCompanyVoicePackageOrderByIds(orderIds));
    }
}
